@@ -1,6 +1,3 @@
-# $File: //depot/OurNet-BBS/BBS/SocketScalar.pm $ $Author: autrijus $
-# $Revision: #3 $ $Change: 1527 $ $DateTime: 2001/08/17 22:51:34 $
-
 package OurNet::BBS::SocketScalar;
 
 use IO::Socket::INET; # XXX Unix Socket: not yet.
@@ -11,7 +8,7 @@ sub TIESCALAR {
     $host .= ":$port" if $port;
 
     my $obj = IO::Socket::INET->new(PeerAddr => $host);
-    print "connected: $host\n" if $OurNet::BBS::DEBUG;
+    print "connected: $host\n";
     my $self = bless(\$obj, $class);
     return $self;
 }
